@@ -3,6 +3,7 @@ require 'arel/factory_methods'
 
 require 'arel/expressions'
 require 'arel/predications'
+require 'arel/window_predications'
 require 'arel/math'
 require 'arel/alias_predication'
 require 'arel/order_predications'
@@ -11,8 +12,6 @@ require 'arel/attributes'
 require 'arel/compatibility/wheres'
 
 #### these are deprecated
-# The Arel::Relation constant is referenced in Rails
-require 'arel/relation'
 require 'arel/expression'
 ####
 
@@ -33,7 +32,7 @@ require 'arel/sql_literal'
 ####
 
 module Arel
-  VERSION = '3.0.2'
+  VERSION = '4.0.0'
 
   def self.sql raw_sql
     Arel::Nodes::SqlLiteral.new raw_sql
