@@ -13,6 +13,7 @@ require 'arel/nodes/false'
 
 # unary
 require 'arel/nodes/unary'
+require 'arel/nodes/grouping'
 require 'arel/nodes/ascending'
 require 'arel/nodes/descending'
 require 'arel/nodes/unqualified_column'
@@ -26,6 +27,7 @@ require 'arel/nodes/join_source'
 require 'arel/nodes/delete_statement'
 require 'arel/nodes/table_alias'
 require 'arel/nodes/infix_operation'
+require 'arel/nodes/over'
 
 # nary
 require 'arel/nodes/and'
@@ -35,9 +37,13 @@ require 'arel/nodes/and'
 # We should make Function a Unary node and deprecate the use of "aliaz"
 require 'arel/nodes/function'
 require 'arel/nodes/count'
+require 'arel/nodes/extract'
 require 'arel/nodes/values'
 require 'arel/nodes/named_function'
 
+# windows
+require 'arel/nodes/window'
+
 # joins
 require 'arel/nodes/inner_join'
 require 'arel/nodes/outer_join'
