@@ -18,6 +18,16 @@ module Arel
         node = Arel::Nodes::Bin.new(Arel.sql('zomg'))
         assert_equal 'BINARY zomg', viz.accept(node)
       end
+
+      def test_equality_with_same_ivars
+        array = [Bin.new('zomg'), Bin.new('zomg')]
+        assert_equal 1, array.uniq.size
+      end
+
+      def test_inequality_with_different_ivars
+        array = [Bin.new('zomg'), Bin.new('zomg!')]
+        assert_equal 2, array.uniq.size
+      end
     end
   end
 end
